This crate provides different encoders and some of their variants, like Base64 or Base32. All of them implement the trait BinaryText in the module binarytext and share a common interface.
Furthermore error types can be found in the mod error. Functions for handling encoding / decoding of byte streams from a source to a destination, e.g. input string decoded to stdout, are provided in the module stream.
Modules
- base16
- Implemention of the Base16 encoder.
- base32
- Implemention of the Base32 encoder and its variants.
- base45
- Implemention of the Base45 encoder.
- base64
- Implemention of the Base64 encoder and its variants.
- base85
- Implemention of the Base85 encoder.
- binarytext
- Definition of the basic trait every encoder needs to implement.
- error
- Defines different error types when encoding / decoding or reading from or writing to files.
- int
- Implementation of IntEncoder used for encoding and decoding integers.
- stream
- This module provides helper functions for encoding / decoding a buffered input stream to a specific destination like stdout or a file. Any source or destination is possible as long as the traits Read or Write are implemented. It is ensured that the input stream is aligned to a multiple of the number of bytes the encoder / decoder expects. Furthermore special characters like newline or carriage return are skipped when decoding.