Module stream

Module stream 

Structs

BinTxtStream
A buffered reader and writer streaming encoded or decoded text from source to destination. For correctly encoding or decoding a stream of bytes, the buffer needs to be aligned to a specific number of bytes. For example using Base64 the buffer has to be a multiple of 3 bytes for encoding and a multiple of 4 bytes for decoding.

Enums

Mode
Decide whether to decode or encode.

Functions

buf_reader_bytes
Helper function for reading from a slice of bytes using BufReader.
buf_reader_file
Helper function for opening files using BufReader.
buf_writer_bytes
Helper function for writing to a string using BufWriter.
buf_writer_file
Helper function for opening files using BufWriter.
buf_writer_stdout
Helper function for writing to stdout using BufWriter.